from pandas import DataFrame, read_csv
from sklearn.preprocessing import normalize


def replace_values(df):
    for column in df.columns:
        df[column].fillna(value=df[column].mean(), inplace=True)
    return df


def filter_dataframe(df):
    relevant_columns = [
        "TOT_HERIDOS_LEVES",
        "TOT_HERIDOS_GRAVES",
        "TOT_VEHICULOS_IMPLICADOS",
        "TOT_MUERTOS",
    ]
    filtered_df = df.filter(items=relevant_columns)
    return filtered_df


def normalize_numerical_values(df):
    filtered_df = filter_dataframe(df=df)
    normalized_data = normalize(X=filtered_df)
    normalized_df = DataFrame(data=normalized_data, columns=filtered_df.columns)
    df.update(normalized_df)
    return df


def parse_data(source):
    df = read_csv(filepath_or_buffer=source, na_values="?")
    processed_df = df.dropna()
    normalized_df = normalize_numerical_values(df=processed_df)
    return normalized_df
